@@ -2,26 +2,32 @@
 # SPDX-License-Identifier: MIT
 
 import board
-import busio
 from adafruit_seesaw.seesaw import Seesaw
 from adafruit_seesaw.digitalio import DigitalIO
+from adafruit_seesaw.rotaryio import IncrementalEncoder
 
-i2c_bus = busio.I2C(board.SCL, board.SDA)
+i2c_bus = board.I2C()
 
 seesaw = Seesaw(i2c_bus, addr=0x36)
 
+seesaw_product = (seesaw.get_version() >> 16) & 0xFFFF
+print("Found product {}".format(seesaw_product))
+if seesaw_product != 4991:
+    print("Wrong firmware loaded?  Expected 4991")
+
 button = DigitalIO(seesaw, 24)
 button_held = False
 
-last_pos = seesaw.get_encoder_pos()
+encoder = IncrementalEncoder(seesaw)
+last_position = None
 
 while True:
 
     # read position of the rotary encoder
-    pos = seesaw.get_encoder_pos()
-    if pos != last_pos:
-        last_pos = pos
-        print(f"Position: {pos}")
+    position = encoder.position
+    if position != last_position:
+        last_position = position
+        print("Position: {}".format(position))
 
     if not button.value and not button_held:
         button_held = True
